Learn R Programming

mlr3inferr (version 0.2.1)

mlr_measures_ci.con_z: Conservative-Z CI

Description

The conservative-z confidence intervals based on the ResamplingPairedSubsampling. Because the variance estimate is obtained using only n / 2 observations, it tends to be conservative. This inference method can also be applied to non-decomposable losses.

Arguments

Point Estimation

For the point estimation, only the first repeats_out resampling iterations will be used, as the other resampling iterations are only used to estimate the variance. This is respected when calling $aggregate() using a standard (non-CI) measure.

Parameters

Only those from MeasureAbstractCi.

Super classes

mlr3::Measure -> mlr3inferr::MeasureAbstractCi -> MeasureCiConZ

Methods

Inherited methods


Method new()

Creates a new instance of this R6 class.

Usage

MeasureCiConZ$new(measure)

Arguments

measure

(Measure or character(1))
A measure of ID of a measure.


Method clone()

The objects of this class are cloneable with this method.

Usage

MeasureCiConZ$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

References

Nadeau, Claude, Bengio, Yoshua (1999). “Inference for the generalization error.” Advances in neural information processing systems, 12.

Examples

Run this code
ci_conz = msr("ci.con_z", "classif.acc")
ci_conz

Run the code above in your browser using DataLab