Learn R Programming

mlr3inferr (version 0.2.1)

mlr_measures_ci.cor_t: Corrected-T CI

Description

Corrected-T confidence intervals based on ResamplingSubsampling. A heuristic factor is applied to correct for the dependence between the iterations. The confidence intervals tend to be liberal. This inference method can also be applied to non-decomposable losses.

Arguments

Parameters

Only those from MeasureAbstractCi.

Super classes

mlr3::Measure -> mlr3inferr::MeasureAbstractCi -> MeasureCiCorrectedT

Methods

Inherited methods


Method new()

Creates a new instance of this R6 class.

Usage

MeasureCiCorrectedT$new(measure)

Arguments

measure

(Measure or character(1))
A measure of ID of a measure.


Method clone()

The objects of this class are cloneable with this method.

Usage

MeasureCiCorrectedT$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

References

Nadeau, Claude, Bengio, Yoshua (1999). “Inference for the generalization error.” Advances in neural information processing systems, 12.

Examples

Run this code
m_cort = msr("ci.cor_t", "classif.acc")
m_cort
rr = resample(
  tsk("sonar"),
  lrn("classif.featureless"),
  rsmp("subsampling", repeats = 10)
)
rr$aggregate(m_cort)

Run the code above in your browser using DataLab