The conservative-z confidence intervals based on the ResamplingPairedSubsampling.
Because the variance estimate is obtained using only n / 2 observations, it tends to be conservative.
This inference method can also be applied to non-decomposable losses.
Arguments
Point Estimation
For the point estimation, only the first repeats_out resampling iterations will be used,
as the other resampling iterations are only used to estimate the variance.
This is respected when calling $aggregate() using a standard (non-CI) measure.