Paired Subsampling to enable inference on the generalization error.
When calling $aggregate() on a resample result obtained using this resampling method, only the first repeats_out iterations will be used.
See section "Point Estimation" of MeasureCiConZ.
repeats_in :: integer(1)
The inner repetitions.
repeats_out :: integer(1)
The outer repetitions.
ratio :: numeric(1)
The proportion of data to use for training.
mlr3::Resampling -> ResamplingPairedSubsampling
iters(integer(1))
The total number of resampling iterations.
unflatten()Unflatten the resampling iteration into a more informative representation:
inner: The subsampling iteration
outer: NA for the first repeats_in iterations. Otherwise it indicates
the outer iteration of the paired subsamplings.
partition: NA for the first repeats_in iterations.
Otherwise it indicates whether the subsampling is applied to the first or second partition
Of the two disjoint halfs.
ResamplingPairedSubsampling$unflatten(iter)iter(integer(1))
Resampling iteration.
list(outer, partition, inner)
clone()The objects of this class are cloneable with this method.
ResamplingPairedSubsampling$clone(deep = FALSE)deepWhether to make a deep clone.
The first repeats_in iterations are a standard ResamplingSubsampling
and should be used to obtain a point estimate of the generalization error.
The remaining iterations should be used to estimate the standard error.
Here, the data is divided repeats_out times into two equally sized disjunct subsets, to each of which subsampling
which, a subsampling with repeats_in repetitions is applied.
See the $unflatten(iter) method to map the iterations to this nested structure.
Nadeau, Claude, Bengio, Yoshua (1999). “Inference for the generalization error.” Advances in neural information processing systems, 12.
pw_subs = rsmp("paired_subsampling")
pw_subs
Run the code above in your browser using DataLab